==> qcpufreq_0.4.0-1.tar.gz: qcpufreq-0.4.0/src/zh.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>MainWindow</name>
    <message>
        <source>File</source>
        <translation>文件</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>Could not get information from /sys!</source>
        <translation>无法从/sys获取信息!</translation>
    </message>
    <message>
        <source>There seems to be a problem with your sudo setup!</source>
        <translation>sudo设置有限问题!</translation>
    </message>
    <message>
        <source>You need to enable overclocking in QCPUFreq&apos;s menu for setting frequencies above 600MHz!</source>
        <translation>设置频率大于600MHz必须在QCPUFreq的菜单栏上启用超频!</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>启用</translation>
    </message>
    <message>
        <source>SmartReflex support is known to be unstable on some devices and may cause random reboots.</source>
        <translation>已知SmartReflex会让设备不稳定并可能引起随机重启.</translation>
    </message>
    <message>
        <source>Please note that overclocking voids your warranty and may break your device! Be careful!</source>
        <translation>注意超频会失去保修并且可能损坏设备!请小心!</translation>
    </message>
    <message>
        <source>QCPUFreq</source>
        <translation>QCPUFreq</translation>
    </message>
    <message>
        <source>Minimum CPU speed:</source>
        <translation>CPU最小频率:</translation>
    </message>
    <message>
        <source>Maximum CPU speed:</source>
        <translation>CPU最大频率:</translation>
    </message>
    <message>
        <source>Set maximum CPU frequency:</source>
        <translation>设置CPU最大频率:</translation>
    </message>
    <message utf8="true">
        <source>SmartReflex™:</source>
        <translation>SmartReflex™:</translation>
    </message>
    <message>
        <source>Enable overclocking</source>
        <translation>启用超频</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>Scaling governor:</source>
        <translation>负载调节器:</translation>
    </message>
    <message>
        <source>CPU temperature:</source>
        <translation>CPU温度:</translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>QCPUFreq</source>
        <translation>QCPUFreq</translation>
    </message>
    <message>
        <source>Cannot open help file!</source>
        <translation>无法打开帮助文件!</translation>
    </message>
</context>
</TS>

==> qcpufreq_0.4.1-1.tar.gz: qcpufreq-0.4.1/src/zh.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>HelpWindow</name>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>QCPUFreq</source>
        <translation>QCPUFreq</translation>
    </message>
    <message>
        <source>Cannot open help file!</source>
        <translation>无法打开帮助文件!</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>File</source>
        <translation>文件</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>Could not get information from /sys!</source>
        <translation>无法从/sys获取信息!</translation>
    </message>
    <message>
        <source>There seems to be a problem with your sudo setup!</source>
        <translation>sudo设置有问题!</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>启用</translation>
    </message>
    <message>
        <source>SmartReflex support is known to be unstable on some devices and may cause random reboots.</source>
        <translation>已知SmartReflex会让设备不稳定并可能引起随机重启.</translation>
    </message>
    <message>
        <source>QCPUFreq</source>
        <translation>QCPUFreq</translation>
    </message>
    <message>
        <source>Minimum CPU speed:</source>
        <translation>CPU最小频率:</translation>
    </message>
    <message>
        <source>Maximum CPU speed:</source>
        <translation>CPU最大频率:</translation>
    </message>
    <message>
        <source>Set maximum CPU frequency:</source>
        <translation>设置CPU最大频率:</translation>
    </message>
    <message utf8="true">
        <source>SmartReflex™:</source>
        <translation>SmartReflex™:</translation>
    </message>
    <message>
        <source>Enable overclocking</source>
        <translation>启用超频</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>Scaling governor:</source>
        <translation>负载调节器:</translation>
    </message>
    <message>
        <source>CPU temperature:</source>
        <translation>CPU温度:</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>You need to enable overclocking in QCPUFreq&apos;s settings in order to set frequencies above 600MHz!</source>
        <translation>必须在QCPUFreq的设置里 启用超频 才能设定600MHz以上的频率!</translation>
    </message>
    <message>
        <source>The current frequency settings have been saved as default.</source>
        <translation>当前的频率设定已被保存为默认值.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Enable overclocking</source>
        <translation>启用超频</translation>
    </message>
    <message>
        <source>Enable auto-rotation</source>
        <translation>启用自动旋转</translation>
    </message>
    <message>
        <source>Load bq27x00_battery module</source>
        <translation>加载bq27x00_battery模块</translation>
    </message>
    <message>
        <source>QCPUFreq</source>
        <translation>QCPUFreq</translation>
    </message>
    <message>
        <source>Could not get information from /sys!</source>
        <translation>无法从/sys获取信息!</translation>
    </message>
    <message>
        <source>Please note that overclocking voids your warranty and may break your device! Be careful!</source>
        <translation>注意超频会失去保修并且可能损坏设备!请小心!</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
</context>
</TS>
